@@ -12,12 +12,13 @@ nEdg <- 0
 nreps <- 10
 acyc <- rep(FALSE,nreps)
 
+stopifnot(require("ggm"))# e.g. isAcyclic() below
 for (i in 1:nreps) {
   myDAG <- randomDAG(p,s,lB,uB)
   amat <- as(myDAG,"matrix")
   acyc[i] <- isAcyclic(amat)
   wgts <- c(wgts,amat[amat!=0])
-  nEdg <- nEdg+numEdges(myDAG)
+  nEdg <- nEdg + graph::numEdges(myDAG)
 }
 
 ## Check number of edges
@@ -28,13 +29,13 @@ if (edge.test$p.value < 0.05) {
 }
 
 ## Check distribution of wgts
-if (min(wgts)<lB | max(wgts)>uB) {
+if (min(wgts) < lB || max(wgts) > uB) {
   stop("Test of randomDAG: Weights are not within specified ranges!")
 }
 
 ## Check whether graphs are acyclic
-if (any(!acyc)) {
+if (!all(acyc))
   stop("Test of randomDAG: Graph is not acyclic!")
-}
 
 
+cat('Time elapsed: ', proc.time(),"\n")
